CDCIDescriptor

Struct CDCIDescriptor 

pub struct CDCIDescriptor {
Show 37 fields pub instance_id: Option<String>, pub stored_width: Option<u32>, pub stored_height: Option<u32>, pub display_width: Option<u32>, pub display_height: Option<u32>, pub active_width: Option<u32>, pub active_height: Option<u32>, pub sample_rate: Option<EditRate>, pub image_aspect_ratio: Option<String>, pub color_primaries: Option<ColorPrimaries>, pub transfer_characteristic: Option<TransferCharacteristic>, pub coding_equations: Option<CodingEquations>, pub picture_compression: Option<VideoCodec>, pub component_depth: Option<u32>, pub frame_layout: Option<String>, pub display_f2_offset: Option<i32>, pub horizontal_subsampling: Option<u32>, pub vertical_subsampling: Option<u32>, pub color_siting: Option<u32>, pub black_ref_level: Option<u32>, pub white_ref_level: Option<u32>, pub color_range: Option<u32>, pub stored_f2_offset: Option<i32>, pub sampled_width: Option<u32>, pub sampled_height: Option<u32>, pub sampled_x_offset: Option<u32>, pub sampled_y_offset: Option<u32>, pub alpha_transparency: Option<String>, pub image_alignment_offset: Option<u32>, pub image_start_offset: Option<u32>, pub image_end_offset: Option<u32>, pub field_dominance: Option<u32>, pub reversed_byte_order: Option<String>, pub padding_bits: Option<i32>, pub alpha_sample_depth: Option<u32>, pub linked_track_id: Option<u32>, pub sub_descriptors: Option<VideoSubDescriptors>,
}
CDCI video descriptor (YCbCr content)

Fields

instance_id: Option<String>stored_width: Option<u32>stored_height: Option<u32>display_width: Option<u32>display_height: Option<u32>active_width: Option<u32>active_height: Option<u32>sample_rate: Option<EditRate>image_aspect_ratio: Option<String>color_primaries: Option<ColorPrimaries>transfer_characteristic: Option<TransferCharacteristic>coding_equations: Option<CodingEquations>picture_compression: Option<VideoCodec>component_depth: Option<u32>frame_layout: Option<String>

Generic Picture Essence Descriptor: Frame Layout “FullFrame” (00h, progressive) or “SeparateFields” (01h, interlaced)

display_f2_offset: Option<i32>

Generic Picture Essence Descriptor: DisplayF2Offset

horizontal_subsampling: Option<u32>

CDCI Descriptor: Horizontal Subsampling (Table 12) 1 = 4:4:4, 2 = 4:2:2

vertical_subsampling: Option<u32>

CDCI Descriptor: Vertical Subsampling (Table 12) Shall be 1

color_siting: Option<u32>

CDCI Descriptor: Color Siting (Table 12) Shall be 0 (CoSiting) but some encoders write a label string (e.g. “CoSiting”).

black_ref_level: Option<u32>

CDCI Descriptor: Black Ref Level (Table 13)

white_ref_level: Option<u32>

CDCI Descriptor: White Ref Level (Table 13)

color_range: Option<u32>

CDCI Descriptor: Color Range (Table 13)

stored_f2_offset: Option<i32>

Table 8: StoredF2Offset — shall not be present

sampled_width: Option<u32>

Table 8: SampledWidth — shall not be present or shall be equal to StoredWidth

sampled_height: Option<u32>

Table 8: SampledHeight — shall not be present or shall be equal to StoredHeight

sampled_x_offset: Option<u32>

Table 8: SampledXOffset — shall not be present or shall be 0

sampled_y_offset: Option<u32>

Table 8: SampledYOffset — shall not be present or shall be 0

alpha_transparency: Option<String>

Table 8: AlphaTransparency — shall not be present

image_alignment_offset: Option<u32>

Table 8: ImageAlignmentOffset — shall not be present

image_start_offset: Option<u32>

Table 8: ImageStartOffset — shall not be present

image_end_offset: Option<u32>

Table 8: ImageEndOffset — shall not be present

field_dominance: Option<u32>

Table 8: FieldDominance — shall be present if interlaced, shall not be present if progressive

reversed_byte_order: Option<String>

Table 12: ReversedByteOrder — shall not be present

padding_bits: Option<i32>

Table 12: PaddingBits — shall not be present

alpha_sample_depth: Option<u32>

Table 12: AlphaSampleDepth — shall not be present

linked_track_id: Option<u32>sub_descriptors: Option<VideoSubDescriptors>