RGBADescriptor

Struct RGBADescriptor 

pub struct RGBADescriptor {
Show 32 fields pub instance_id: Option<String>, pub display_width: Option<u32>, pub display_height: Option<u32>, pub stored_width: Option<u32>, pub stored_height: Option<u32>, pub sample_rate: Option<EditRate>, pub image_aspect_ratio: Option<String>, pub color_primaries: Option<ColorPrimaries>, pub transfer_characteristic: Option<TransferCharacteristic>, pub coding_equations: Option<CodingEquations>, pub picture_compression: Option<VideoCodec>, pub frame_layout: Option<String>, pub display_f2_offset: Option<i32>, pub component_max_ref: Option<u32>, pub component_min_ref: Option<u32>, pub scanning_direction: Option<String>, pub stored_f2_offset: Option<i32>, pub sampled_width: Option<u32>, pub sampled_height: Option<u32>, pub sampled_x_offset: Option<u32>, pub sampled_y_offset: Option<u32>, pub alpha_transparency: Option<String>, pub image_alignment_offset: Option<u32>, pub image_start_offset: Option<u32>, pub image_end_offset: Option<u32>, pub field_dominance: Option<u32>, pub alpha_max_ref: Option<u32>, pub alpha_min_ref: Option<u32>, pub palette: Option<String>, pub palette_layout: Option<String>, pub linked_track_id: Option<u32>, pub sub_descriptors: Option<VideoSubDescriptors>,
}
RGBA video descriptor (JPEG 2000 RGB content)

Fields

instance_id: Option<String>display_width: Option<u32>display_height: Option<u32>stored_width: Option<u32>stored_height: Option<u32>sample_rate: Option<EditRate>image_aspect_ratio: Option<String>color_primaries: Option<ColorPrimaries>transfer_characteristic: Option<TransferCharacteristic>coding_equations: Option<CodingEquations>picture_compression: Option<VideoCodec>frame_layout: Option<String>

Generic Picture Essence Descriptor: Frame Layout “FullFrame” (00h, progressive) or “SeparateFields” (01h, interlaced)

display_f2_offset: Option<i32>

Generic Picture Essence Descriptor: DisplayF2Offset

component_max_ref: Option<u32>

RGBA Descriptor: Component Max Ref (Table 10/11)

component_min_ref: Option<u32>

RGBA Descriptor: Component Min Ref (Table 10/11)

scanning_direction: Option<String>

RGBA Descriptor: Scanning Direction (Table 10) Shall be “ScanningDirection_LeftToRightTopToBottom” (00h)

stored_f2_offset: Option<i32>

Table 8: StoredF2Offset — shall not be present

sampled_width: Option<u32>

Table 8: SampledWidth — shall not be present or shall be equal to StoredWidth

sampled_height: Option<u32>

Table 8: SampledHeight — shall not be present or shall be equal to StoredHeight

sampled_x_offset: Option<u32>

Table 8: SampledXOffset — shall not be present or shall be 0

sampled_y_offset: Option<u32>

Table 8: SampledYOffset — shall not be present or shall be 0

alpha_transparency: Option<String>

Table 8: AlphaTransparency — shall not be present

image_alignment_offset: Option<u32>

Table 8: ImageAlignmentOffset — shall not be present

image_start_offset: Option<u32>

Table 8: ImageStartOffset — shall not be present

image_end_offset: Option<u32>

Table 8: ImageEndOffset — shall not be present

field_dominance: Option<u32>

Table 8: FieldDominance — shall be present if interlaced, shall not be present if progressive

alpha_max_ref: Option<u32>

Table 10: AlphaMaxRef — shall not be present

alpha_min_ref: Option<u32>

Table 10: AlphaMinRef — shall not be present

palette: Option<String>

Table 10: Palette — shall not be present

palette_layout: Option<String>

Table 10: PaletteLayout — shall not be present

linked_track_id: Option<u32>sub_descriptors: Option<VideoSubDescriptors>