pub struct CompositionPlaylist {Show 19 fields
pub namespace: CplNamespace,
pub id: ImfUuid,
pub annotation: Option<LanguageString>,
pub issue_date: String,
pub issuer: Option<LanguageString>,
pub creator: Option<LanguageString>,
pub content_originator: Option<LanguageString>,
pub content_title: LanguageString,
pub content_kind: ContentKindElement,
pub content_version_list: Option<ContentVersionList>,
pub essence_descriptor_list: Option<EssenceDescriptorList>,
pub edit_rate: Option<EditRate>,
pub total_running_time: Option<String>,
pub locale_list: Option<LocaleList>,
pub extension_properties: Option<ExtensionProperties>,
pub composition_timecode: Option<CompositionTimecode>,
pub has_signer: bool,
pub has_signature: bool,
pub segment_list: SegmentList,
}Expand description
Root CPL structure - defines a complete IMF composition
Fields
namespace: CplNamespaceThe SMPTE spec version detected from the root xmlns of the CPL XML.
Set after deserialization by parse_cpl().
id: ImfUuidannotation: Option<LanguageString>issue_date: Stringissuer: Option<LanguageString>creator: Option<LanguageString>content_originator: Option<LanguageString>content_title: LanguageStringcontent_kind: ContentKindElementcontent_version_list: Option<ContentVersionList>essence_descriptor_list: Option<EssenceDescriptorList>edit_rate: Option<EditRate>total_running_time: Option<String>locale_list: Option<LocaleList>extension_properties: Option<ExtensionProperties>composition_timecode: Option<CompositionTimecode>has_signer: boolWhether the original CPL XML contained a <Signer> element.
Set by parse_cpl() from raw XML before namespace stripping.
has_signature: boolWhether the original CPL XML contained a <Signature> element.
Set by parse_cpl() from raw XML before namespace stripping.
segment_list: SegmentListTrait Implementations
Sourceimpl Debug for CompositionPlaylist
impl Debug for CompositionPlaylist
Sourceimpl<'de> Deserialize<'de> for CompositionPlaylist
impl<'de> Deserialize<'de> for CompositionPlaylist
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CompositionPlaylist
impl PartialEq for CompositionPlaylist
Sourcefn eq(&self, other: &CompositionPlaylist) -> bool
fn eq(&self, other: &CompositionPlaylist) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompositionPlaylist
impl Serialize for CompositionPlaylist
impl StructuralPartialEq for CompositionPlaylist